@@ -6,10 +6,9 @@ use Config::Auto;
 use Cwd;
 use warnings;
 use strict;
-our $VERSION = '2.2.4';
 
 # Version of dpkg-cross environment.
-my $DPKGCROSSVERSION = "2.2.4";
+my $DPKGCROSSVERSION = "2.3.0";
 
 require Exporter;
 
@@ -107,7 +106,7 @@ $progname = basename($0);
 	'openbsd-i386' => 'i386-openbsd', #XXX This differs from dpkg-architecture
 	'freebsd-i386' => 'i386-freebsd', #XXX This differs from dpkg-architecture
 	'darwin-i386' => 'i386-darwin',   #XXX This differs from dpkg-architecture
-	'win32-i386' => 'i386-cygwin'
+	'win32-i386' => 'i386-cygwin',
 );
 
 # Regexps to parse 'file' output to detect arch of ELF binary
@@ -332,7 +331,7 @@ returns undef on error
 
 =cut
 
-sub convert_filename ($) {
+sub convert_filename {
 	my $name = shift;
 	return undef if (!defined($name));
 	return undef if ($name !~ /\.deb$/);
@@ -386,7 +385,7 @@ returns the DPKG_HOST_GNU_TYPE or undef
 
 =cut
 
-sub check_arch($) {
+sub check_arch {
 	my $check = shift;
 	my $deb_host_gnu_type;
 	chomp($deb_host_gnu_type = `CC="" dpkg-architecture -f -a$check -qDEB_HOST_GNU_TYPE 2> /dev/null`);
@@ -406,12 +405,13 @@ return: none
 
 =cut
 
-sub setup() {
+sub setup {
 	my ($var_, $os_, $scope_);
 	# Set '$arch' to defaults if not already specified.
 	$arch = &get_architecture();
 	die "$progname: Architecture is not specified.\n" unless ($arch);
-	chomp($deb_host_gnu_type = `CC="" dpkg-architecture -f -a$arch -qDEB_HOST_GNU_TYPE 2> /dev/null`);
+	$deb_host_gnu_type = `CC="" dpkg-architecture -f -a$arch -qDEB_HOST_GNU_TYPE 2> /dev/null`;
+	chomp($deb_host_gnu_type);
 	$deb_host_gnu_type ||= $archtable{$arch};
 
 	# Finalize, no subst possible crossbase.
@@ -474,7 +474,7 @@ return: Full directory pathname, undef if failed
 
 =cut
 
-sub create_tmpdir ($) {
+sub create_tmpdir {
 	my $name = shift;
 	my $pd = $ENV{'TMPDIR'} && -d $ENV{'TMPDIR'}
 		? $ENV{'TMPDIR'}
@@ -500,7 +500,7 @@ return: Converted path.
 
 =cut
 
-sub convert_path ($) {
+sub convert_path {
 	my $path = &simplify_path ($_[0]);
 	if ($path =~ /^\/usr(\/X11R6)?\/include\//) {
 		$path = "$crossinc/$'";
@@ -510,6 +510,8 @@ sub convert_path ($) {
 		$path = "$crosslib64/$'";
 	} elsif ($path =~ /^(\/usr(\/X11R6)?)?\/lib32\//) {
 		$path = "$crosslib32/$'";
+	} elsif ($path =~ m:^(/emul/ia32-linux/(usr/)?lib/):) {
+		$path = "$crosslib32/$'";
 	} elsif ($path =~ /^\/usr\/\w+-\w+(-\w+(-\w+)?)?\//) {
 		# leave alone
 	} else {
@@ -528,7 +530,7 @@ return: Simplified path.
 
 =cut
 
-sub simplify_path ($) {
+sub simplify_path {
 	my $path = $_[0];
 	# This will remove duplicate slashes
 	$path =~ s/\/+/\//g;
@@ -877,7 +879,7 @@ of usage of LD_LIBRARY_PATH by fakeroot.
 
 =cut
 
-sub convert_ld_library_path () {
+sub convert_ld_library_path {
 	return if (!defined($ENV{'LD_LIBRARY_PATH'}));
 	my @list = split(':', $ENV{'LD_LIBRARY_PATH'});
 	$ENV{'LD_LIBRARY_PATH'} = join(':', grep {$_ =~ /^\/usr\/(lib|share)\//} @list);
